# Steamship Python Client Library

Steamship is the fastest way to build, ship, and use full-lifecycle language AI.

## Installing

Install via pip:

```
pip install steamship
```

We also recommend installing the Steamship CLI for project management:

```
npm install -g @steamship/cli
```

